@@ -1,14 +1,14 @@
 #' Simulation from dependence models
-#' 
+#'
 #' Simulate Monte Carlo sample from a collection of fitted conditional
 #' dependence models.
-#' 
+#'
 #' Generates a Monte Carlo sample of the required size from a collection of
 #' conditional multivariate extreme values model of Heffernan and Tawn, 2004.
 #' For each marginal variable, the model that conditions on that margin is used
 #' to simulate values in the part of the sample space for which that margin is
 #' the largest of all marignal variables (measured on a quantile scale).
-#' 
+#'
 #' @usage mexMonteCarlo(nSample,mexList,mult=10)
 #' @param nSample Required sample size.
 #' @param mexList List of fitted dependence models (returned by
@@ -16,7 +16,7 @@
 #' @param mult Integer specifying what multiple of the total number of points
 #' should be generated for rejection sample
 #' @return A list with the following components:
-#' 
+#'
 #' \item{nR}{For each margin, number of original Monte Carlo points replaced by
 #' points generated under the corresponding conditional model.}
 #' \item{MCsample}{Matrix contiaining the Monte Carlo sample, dimension
@@ -31,25 +31,25 @@
 #' 497 -- 546, 2004
 #' @keywords models multivariate
 #' @examples
-#' \donttest{ 
+#' \donttest{
 #'   mAll <- mexAll(winter,mqu=0.7,dqu=c(0.7,0.7,0.7,0.7,0.7))
 #'   mexMC <- mexMonteCarlo(5000,mAll)
 #'   pairs(mexMC$MCsample)
 #' }
 #' @export mexMonteCarlo
-mexMonteCarlo <- function(nSample,mexList,mult=10){
+mexMonteCarlo <- function(nSample, mexList, mult=10){
 #set up
   d <- length(mexList)
   data <- mexList[[1]]$margins$data
   margins <- mexList[[1]]$dependence$margins
   nData <- dim(data)[1]
-#Generate our Monte Carlo sample from the original dataset. 
+#Generate our Monte Carlo sample from the original dataset.
   which <- sample(1:nData, size=nSample, replace = TRUE)
   MCsampleOriginal <- data[which,]
-#Transform the original dataset to the Laplace scale. 
+#Transform the original dataset to the Laplace scale.
   dataLaplace <- mexTransform(mexList[[1]]$margins, margins = margins, method = "mixture")$transformed
   MCsampleLaplace <- dataLaplace[which,]
-#Identify maximum components. 
+#Identify maximum components.
   whichMax <- apply(MCsampleLaplace,1,which.max)
 # Now identify which of the maximal components lie above their associated conditional dependence model thresholds.
   dth <- sapply(mexList,function(l)l$dependence$dth)
@@ -57,9 +57,10 @@ mexMonteCarlo <- function(nSample,mexList,mult=10){
   whichMaxAboveThresh <- sapply(1:nSample,function(i)MCsampleLaplace[i,whichMax[i]] >= dth[whichMax[i]])
 # generate large samples from each of the Conditional models,
   mexKeep <- lapply(1:d,function(i){
-      mc <- predict.mex(mexList[[i]],pqu=dqu[i],nsim=nSample*d*mult)
-      mc$data$simulated[mc$data$CondLargest,order(c(i,c(1:d)[-i]))]}) 
-# Replace original sample by samples from conditional models. 
+    mc <- predict.mex(mexList[[i]],pqu=dqu[i],nsim=nSample*d*mult)
+    mc$data$simulated[mc$data$CondLargest,order(c(i,c(1:d)[-i]))]
+  })
+# Replace original sample by samples from conditional models.
   nR <- rep(0,d)
   names(nR) <- names(data)
   for(i in 1:d){
